Unified metadata types for image formats.
This module provides format-agnostic metadata structures that represent a superset of all metadata that can exist in any supported RAW format. Extend as new formats reveal additional fields.
Structs
- Camera
Info - Camera identification information.
- Date
Time Info - Date/time information.
- DngCalibration
Info - DNG calibration and noise data.
- DngColor
Info - DNG color calibration data.
- DngProfile
Info - DNG profile data.
- Exif
Info - EXIF exposure and capture settings.
- GpsInfo
- GPS geolocation data.
- Image
Info - Image-level metadata.
- Image
Metadata - Complete image metadata — unified superset of all supported formats.
- Metadata
Entry - One entry in the generic metadata table (
ImageMetadata::extra). - Metadata
Key - Fully-qualified key into
ImageMetadata::extra. - SRational
- Signed rational (numerator, denominator).
- URational
- Unsigned rational (numerator, denominator).
Enums
- Metadata
Namespace - Namespace identifying the origin of a generic metadata tag.
- Metadata
Value - A typed, format-agnostic metadata value.
Traits
- Metadata
Extractor - Trait for extracting unified metadata from format-specific structures.