Pixel type system for generic image processing.
Provides traits and type aliases for working with different pixel representations (u8, u16, f32) in a uniform way.
Structs
Traits
- FromF32
- Conversion trait from f32 to a sample type.
- Sample
- Trait for scalar sample values used in image processing.
Functions
- rgb16_
from_ interleaved - Convert a slice of interleaved u16 RGB data to a Vec of Rgb16 pixels.
- rgb16_
to_ interleaved - Convert a slice of Rgb16 pixels to interleaved u16 data.